@@ -70,7 +70,7 @@ func GetVersionInfo() versionInfo { //revive:disable:unexported-return
 	}
 }
 
-func main() {
+func printSplash() {
 	versionInfo := GetVersionInfo()
 	fmt.Printf(`
   __    _   ___  
@@ -78,14 +78,13 @@ func main() {
 /_/--\ |_| |_| \_ %s, built with Go %s
 
 `, versionInfo.airVersion, versionInfo.goVersion)
+}
 
+func main() {
 	if showVersion {
+		printSplash()
 		return
 	}
-
-	if debugMode {
-		fmt.Println("[debug] mode")
-	}
 	sigs := make(chan os.Signal, 1)
 	signal.Notify(sigs, syscall.SIGINT, syscall.SIGTERM, syscall.SIGHUP)
 
@@ -96,6 +95,12 @@ func main() {
 		return
 	}
 	cfg.WithArgs(cmdArgs)
+	if !cfg.Log.Silent {
+		printSplash()
+	}
+	if debugMode && !cfg.Log.Silent {
+		fmt.Println("[debug] mode")
+	}
 	r, err := runner.NewEngineWithConfig(cfg, debugMode)
 	if err != nil {
 		log.Fatal(err)
