@@ -9,7 +9,6 @@ import (
 	"reflect"
 	"regexp"
 	"runtime"
-	"strings"
 	"time"
 
 	"dario.cat/mergo"
@@ -308,7 +307,6 @@ func (c *Config) preprocess() error {
 	if c.TestDataDir == "" {
 		c.TestDataDir = "testdata"
 	}
-
 	ed := c.Build.ExcludeDir
 	for i := range ed {
 		ed[i] = cleanPath(ed[i])
@@ -329,9 +327,6 @@ func (c *Config) preprocess() error {
 	// CMD will not recognize relative path like ./tmp/server
 	c.Build.Bin, err = filepath.Abs(c.Build.Bin)
 
-	// Account for spaces in filepath
-	c.Build.Bin = fmt.Sprintf("%q", c.Build.Bin)
-
 	return err
 }
 
@@ -367,8 +362,7 @@ func (c *Config) killDelay() time.Duration {
 }
 
 func (c *Config) binPath() string {
-	bin := strings.Trim(c.Build.Bin, "\"")
-	return fmt.Sprintf("%q", filepath.Join(c.Root, bin))
+	return filepath.Join(c.Root, c.Build.Bin)
 }
 
 func (c *Config) tmpPath() string {
