@@ -2,14 +2,12 @@ package runner
 
 import (
 	"bytes"
-	"errors"
 	"fmt"
 	"io"
 	"log"
 	"net/http"
 	"strconv"
 	"strings"
-	"syscall"
 	"time"
 )
 
@@ -68,10 +66,7 @@ func (p *Proxy) injectLiveReload(resp *http.Response) (string, error) {
 		return page, nil
 	}
 
-	script := fmt.Sprintf(
-		`<script>new EventSource("http://localhost:%d/internal/reload").onmessage = () => { location.reload() }</script>`,
-		p.config.ProxyPort,
-	)
+	script := `<script>new EventSource("/internal/reload").onmessage = () => { location.reload() }</script>`
 	return page[:body] + script + page[body:], nil
 }
 
@@ -106,18 +101,24 @@ func (p *Proxy) proxyHandler(w http.ResponseWriter, r *http.Request) {
 	}
 	req.Header.Set("X-Forwarded-For", r.RemoteAddr)
 
-	// retry on connection refused error since after a file change air will restart the server and it may take a few milliseconds for the server to be up-and-running.
+	// set the via header
+	viaHeaderValue := fmt.Sprintf("%s %s", r.Proto, r.Host)
+	req.Header.Set("Via", viaHeaderValue)
+
+	// air will restart the server. it may take a few milliseconds for it to start back up.
+	// therefore, we retry until the server becomes available or this retry loop exits with an error.
 	var resp *http.Response
+	resp, err = p.client.Do(req)
 	for i := 0; i < 10; i++ {
-		resp, err = p.client.Do(req)
 		if err == nil {
 			break
 		}
-		if !errors.Is(err, syscall.ECONNREFUSED) {
-			http.Error(w, "proxy handler: unable to reach app", http.StatusInternalServerError)
-			return
-		}
 		time.Sleep(100 * time.Millisecond)
+		resp, err = p.client.Do(req)
+	}
+	if err != nil {
+		http.Error(w, "proxy handler: unable to reach app", http.StatusInternalServerError)
+		return
 	}
 	defer resp.Body.Close()
 
@@ -130,6 +131,7 @@ func (p *Proxy) proxyHandler(w http.ResponseWriter, r *http.Request) {
 			w.Header().Add(k, v)
 		}
 	}
+	w.Header().Add("Via", viaHeaderValue)
 	w.WriteHeader(resp.StatusCode)
 
 	if !strings.Contains(resp.Header.Get("Content-Type"), "text/html") {
